import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';

import { Router } from '@angular/router';

interface DesignItem {
  image: string;
  title: string;
  date: string;
}

interface FavoriteItem {
  image: string;
  title: string;
  author: string;
}

@Component({
  selector: 'app-page-mine',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './page-mine.html',
  styleUrls: ['./page-mine.scss']
})
export class PageMineComponent {

constructor(private router: Router) {}

  // 用户信息
  user = {
    name: '用户昵称',
    level: '黄金会员',
    avatar: 'assets/images/user-avatar.png' // 本地头像图片
  };

  // 我的设计数据
  myDesigns: DesignItem[] = [
    {
      image: 'assets/images/my-design1.jpg',
      title: '蓝色风暴',
      date: '3天前'
    },
    {
      image: 'assets/images/my-design2.jpg',
      title: '红黑经典',
      date: '1周前'
    }
  ];

  // 我的收藏数据
  favorites: FavoriteItem[] = [
    {
      image: 'assets/images/fav1.jpg',
      title: '星空主题',
      author: 'by 设计师小王'
    },
    {
      image: 'assets/images/fav2.jpg',
      title: '火焰纹路',
      author: 'by 创意达人'
    }
  ];

  // 处理图片加载错误
  handleImageError(event: Event) {
    const img = event.target as HTMLImageElement;
    img.src = 'assets/images/default-placeholder.png';
    img.onerror = null; // 防止无限循环
  }


  
openSettings() {
    // 实际项目中可以导航到设置页面或打开设置模态框
    console.log('打开设置');
    this.router.navigate(['/settings']); // 或使用模态框
  }


  // 退出登录
  logout() {
    alert('退出登录功能需要后端支持，此处为前端演示');
    // 实际项目中这里会有路由跳转到登录页




 if (confirm('确定要退出登录吗？')) {
      // 实际项目中这里应该清除用户认证信息
      localStorage.removeItem('authToken');
      
      // 导航到登录页面
      this.router.navigate(['/login']);
      
      // 显示退出成功提示
      alert('您已成功退出登录');
    }





    
  }
}